Citing
======

To cite ArrayLSTM please use the following publications:

van Ede, T., Aghakhani, H., Spahn, N., Bortolameotti, R., Cova, M., Continella, A., van Steen, M., Peter, A., Kruegel, C. & Vigna, G. (2022, May). DeepCASE: Semi-Supervised Contextual Analysis of Security Events. In 2022 Proceedings of the IEEE Symposium on Security and Privacy (S&P). IEEE.
[`PDF DeepCASE`_]

Rocki, K.M. (2016). Recurrent memory array structures. In arXiv preprint arXiv:1607.03085.
[`PDF ArrayLSTM`_]

.. _`PDF DeepCASE`: https://vm-thijs.ewi.utwente.nl/static/homepage/papers/deepcase.pdf

.. _`PDF ArrayLSTM`: https://arxiv.org/abs/1607.03085

Bibtex
^^^^^^

DeepCASE
~~~~~~~~

.. code::

  @inproceedings{vanede2020deepcase,
    title={{DeepCASE: Semi-Supervised Contextual Analysis of Security Events}},
    author={van Ede, Thijs and Aghakhani, Hojjat and Spahn, Noah and Bortolameotti, Riccardo and Cova, Marco and Continella, Andrea and van Steen, Maarten and Peter, Andreas and Kruegel, Christopher and Vigna, Giovanni},
    booktitle={Proceedings of the IEEE Symposium on Security and Privacy (S&P)},
    year={2022},
    organization={IEEE}
  }


ArrayLSTM
~~~~~~~~~

.. code::

  @article{rocki2016recurrent,
    title={Recurrent memory array structures},
    author={Rocki, Kamil},
    journal={arXiv preprint arXiv:1607.03085},
    year={2016}
  }
